==> yhmgit-0.1.tar.gz: yhmgit-0.1/setup.py <==
from distutils.core import setup

setup(
    name='yhmgit',  # How you named your package folder (MyLib)
    packages=['yhmgit'],  # Chose the same as "name"
    version='0.1',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='yh branch git manager util',  # Give a short description about your library
    author='yonghuifan21',  # Type in your name
    author_email='jackfan1@yonghui.com',  # Type in your E-Mail
    url='http://gitlab.yonghui.cn/operation-xm-qdjg/yhgit.git',  # Provide either the link to your github or to your website
    download_url='https://github.com/yonghuifan21/yhci-util/blob/master/dist/yhciutil-0.1.tar.gz',  # I explain this later on
    keywords=['yhciutil', 'yhci', 'ciutil'],  # Keywords that define your package best
    install_requires=[  # I get to this in a second
        'ruamel.yaml',
        'datetime',
        'Repo',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',  # Again, pick a license
        'Programming Language :: Python :: 3',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)

==> yhmgit-0.2.tar.gz: yhmgit-0.2/setup.py <==
from distutils.core import setup

setup(
    name='yhmgit',  # How you named your package folder (MyLib)
    packages=['yhmgit'],  # Chose the same as "name"
    version='0.2',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='yh branch git manager util',  # Give a short description about your library
    author='yonghuifan21',  # Type in your name
    author_email='jackfan1@yonghui.com',  # Type in your E-Mail
    url='http://gitlab.yonghui.cn/operation-xm-qdjg/yhgit.git',  # Provide either the link to your github or to your website
    download_url='https://files.pythonhosted.org/packages/08/7d/95aa3aa88c4c195889993de691b7fe816ac8d0767ea22fce56ccd240169a/yhmgit-0.2.tar.gz',  # I explain this later on
    keywords=['yhciutil', 'yhci', 'ciutil'],  # Keywords that define your package best
    install_requires=[  # I get to this in a second
        'ruamel.yaml',
        'datetime',
        'Repo',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',  # Again, pick a license
        'Programming Language :: Python :: 3',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
